==> megfile-0.0.3.post1-py3-none-any.whl: megfile/__init__.py <==
from megfile.fs import fs_abspath, fs_access, fs_cwd, fs_exists, fs_expanduser, fs_getmd5, fs_getmtime, fs_getsize, fs_glob, fs_glob_stat, fs_home, fs_iglob, fs_isabs, fs_isdir, fs_isfile, fs_islink, fs_ismount, fs_listdir, fs_load_from, fs_makedirs, fs_move, fs_realpath, fs_relpath, fs_remove, fs_rename, fs_resolve, fs_save_as, fs_scan, fs_scan_stat, fs_scandir, fs_stat, fs_sync, fs_unlink, fs_walk, is_fs
from megfile.fs_path import FSPath
from megfile.http_path import HttpPath, HttpsPath
from megfile.s3 import is_s3, s3_access, s3_buffered_open, s3_cached_open, s3_copy, s3_download, s3_exists, s3_getmd5, s3_getmtime, s3_getsize, s3_glob, s3_glob_stat, s3_hasbucket, s3_iglob, s3_isdir, s3_isfile, s3_legacy_open, s3_listdir, s3_load_content, s3_load_from, s3_makedirs, s3_memory_open, s3_move, s3_open, s3_path_join, s3_pipe_open, s3_prefetch_open, s3_remove, s3_rename, s3_save_as, s3_scan, s3_scan_stat, s3_scandir, s3_stat, s3_sync, s3_unlink, s3_upload, s3_walk
from megfile.s3_path import S3Path
from megfile.smart import IMAGE_EXTNAMES, smart_access, smart_cache, smart_combine_open, smart_copy, smart_exists, smart_getmd5, smart_getmtime, smart_getsize, smart_glob, smart_glob_stat, smart_iglob, smart_isdir, smart_isfile, smart_islink, smart_listdir, smart_load_content, smart_load_from, smart_load_image_metadata, smart_load_text, smart_makedirs, smart_move, smart_open, smart_path_join, smart_realpath, smart_remove, smart_rename, smart_save_as, smart_save_content, smart_save_text, smart_scan, smart_scan_stat, smart_scandir, smart_stat, smart_sync, smart_touch, smart_unlink, smart_walk
from megfile.smart_path import SmartPath
from megfile.stdio_path import StdioPath
from megfile.version import VERSION as __version__

__all__ = [
    'is_fs',
    'is_s3',
    'smart_access',
    'smart_cache',
    'smart_combine_open',
    'smart_copy',
    'smart_exists',
    'smart_getmtime',
    'smart_getsize',
    'smart_glob_stat',
    'smart_glob',
    'smart_iglob',
    'smart_isdir',
    'smart_isfile',
    'smart_islink',
    'smart_listdir',
    'smart_load_content',
    'smart_save_content',
    'smart_load_from',
    'smart_load_image_metadata',
    'smart_load_text',
    'smart_save_text',
    'smart_makedirs',
    'smart_open',
    'smart_path_join',
    'smart_realpath',
    'smart_remove',
    'smart_move',
    'smart_rename',
    'smart_save_as',
    'smart_scan_stat',
    'smart_scan',
    'smart_scandir',
    'smart_stat',
    'smart_sync',
    'smart_touch',
    'smart_unlink',
    'smart_walk',
    'smart_cache',
    'smart_getmd5',
    's3_access',
    's3_buffered_open',
    's3_cached_open',
    's3_copy',
    's3_download',
    's3_exists',
    's3_getmd5',
    's3_getmtime',
    's3_getsize',
    's3_glob_stat',
    's3_glob',
    's3_hasbucket',
    's3_iglob',
    's3_isdir',
    's3_isfile',
    's3_legacy_open',
    's3_listdir',
    's3_load_content',
    's3_load_from',
    's3_makedirs',
    's3_memory_open',
    's3_open',
    's3_path_join',
    's3_pipe_open',
    's3_prefetch_open',
    's3_remove',
    's3_rename',
    's3_move',
    's3_sync',
    's3_save_as',
    's3_scan_stat',
    's3_scan',
    's3_scandir',
    's3_stat',
    's3_unlink',
    's3_upload',
    's3_walk',
    'fs_abspath',
    'fs_access',
    'fs_exists',
    'fs_getmtime',
    'fs_getsize',
    'fs_glob_stat',
    'fs_glob',
    'fs_iglob',
    'fs_isabs',
    'fs_isdir',
    'fs_isfile',
    'fs_islink',
    'fs_ismount',
    'fs_listdir',
    'fs_load_from',
    'fs_makedirs',
    'fs_realpath',
    'fs_relpath',
    'fs_remove',
    'fs_rename',
    'fs_move',
    'fs_sync',
    'fs_save_as',
    'fs_scan_stat',
    'fs_scan',
    'fs_scandir',
    'fs_stat',
    'fs_unlink',
    'fs_walk',
    'fs_cwd',
    'fs_home',
    'fs_expanduser',
    'fs_resolve',
    'fs_getmd5',
    'IMAGE_EXTNAMES',
    'S3Path',
    'FSPath',
    'HttpPath',
    'HttpsPath',
    'StdioPath',
    'SmartPath',
]

# deprecation warnings
import warnings  # isort:skip


def s3_get_md5(s3_url):
    warnings.warn(
        "s3_get_md5 is deprecated, use s3_getmd5 instead", DeprecationWarning)
    return s3_getmd5(s3_url)


def smart_get_image_metadata(path):
    warnings.warn(
        "smart_get_image_metadata is deprecated, use smart_load_image_metadata instead",
        DeprecationWarning)
    return smart_load_image_metadata(path)

==> megfile-0.0.9-py3-none-any.whl: megfile/__init__.py <==
from megfile.fs import fs_abspath, fs_access, fs_cwd, fs_exists, fs_expanduser, fs_getmd5, fs_getmtime, fs_getsize, fs_glob, fs_glob_stat, fs_home, fs_iglob, fs_isabs, fs_isdir, fs_isfile, fs_islink, fs_ismount, fs_listdir, fs_load_from, fs_makedirs, fs_move, fs_realpath, fs_relpath, fs_remove, fs_rename, fs_resolve, fs_save_as, fs_scan, fs_scan_stat, fs_scandir, fs_stat, fs_sync, fs_unlink, fs_walk, is_fs
from megfile.fs_path import FSPath
from megfile.http_path import HttpPath, HttpsPath
from megfile.s3 import is_s3, s3_access, s3_buffered_open, s3_cached_open, s3_copy, s3_download, s3_exists, s3_getmd5, s3_getmtime, s3_getsize, s3_glob, s3_glob_stat, s3_hasbucket, s3_iglob, s3_isdir, s3_isfile, s3_legacy_open, s3_listdir, s3_load_content, s3_load_from, s3_makedirs, s3_memory_open, s3_move, s3_open, s3_path_join, s3_pipe_open, s3_prefetch_open, s3_remove, s3_rename, s3_save_as, s3_scan, s3_scan_stat, s3_scandir, s3_stat, s3_sync, s3_unlink, s3_upload, s3_walk
from megfile.s3_path import S3Path
from megfile.smart import smart_access, smart_cache, smart_combine_open, smart_copy, smart_exists, smart_getmd5, smart_getmtime, smart_getsize, smart_glob, smart_glob_stat, smart_iglob, smart_isdir, smart_isfile, smart_islink, smart_listdir, smart_load_content, smart_load_from, smart_load_text, smart_makedirs, smart_move, smart_open, smart_path_join, smart_realpath, smart_remove, smart_rename, smart_save_as, smart_save_content, smart_save_text, smart_scan, smart_scan_stat, smart_scandir, smart_stat, smart_sync, smart_touch, smart_unlink, smart_walk
from megfile.smart_path import SmartPath
from megfile.stdio_path import StdioPath
from megfile.version import VERSION as __version__

__all__ = [
    'is_fs',
    'is_s3',
    'smart_access',
    'smart_cache',
    'smart_combine_open',
    'smart_copy',
    'smart_exists',
    'smart_getmtime',
    'smart_getsize',
    'smart_glob_stat',
    'smart_glob',
    'smart_iglob',
    'smart_isdir',
    'smart_isfile',
    'smart_islink',
    'smart_listdir',
    'smart_load_content',
    'smart_save_content',
    'smart_load_from',
    'smart_load_text',
    'smart_save_text',
    'smart_makedirs',
    'smart_open',
    'smart_path_join',
    'smart_realpath',
    'smart_remove',
    'smart_move',
    'smart_rename',
    'smart_save_as',
    'smart_scan_stat',
    'smart_scan',
    'smart_scandir',
    'smart_stat',
    'smart_sync',
    'smart_touch',
    'smart_unlink',
    'smart_walk',
    'smart_cache',
    'smart_getmd5',
    's3_access',
    's3_buffered_open',
    's3_cached_open',
    's3_copy',
    's3_download',
    's3_exists',
    's3_getmd5',
    's3_getmtime',
    's3_getsize',
    's3_glob_stat',
    's3_glob',
    's3_hasbucket',
    's3_iglob',
    's3_isdir',
    's3_isfile',
    's3_legacy_open',
    's3_listdir',
    's3_load_content',
    's3_load_from',
    's3_makedirs',
    's3_memory_open',
    's3_open',
    's3_path_join',
    's3_pipe_open',
    's3_prefetch_open',
    's3_remove',
    's3_rename',
    's3_move',
    's3_sync',
    's3_save_as',
    's3_scan_stat',
    's3_scan',
    's3_scandir',
    's3_stat',
    's3_unlink',
    's3_upload',
    's3_walk',
    'fs_abspath',
    'fs_access',
    'fs_exists',
    'fs_getmtime',
    'fs_getsize',
    'fs_glob_stat',
    'fs_glob',
    'fs_iglob',
    'fs_isabs',
    'fs_isdir',
    'fs_isfile',
    'fs_islink',
    'fs_ismount',
    'fs_listdir',
    'fs_load_from',
    'fs_makedirs',
    'fs_realpath',
    'fs_relpath',
    'fs_remove',
    'fs_rename',
    'fs_move',
    'fs_sync',
    'fs_save_as',
    'fs_scan_stat',
    'fs_scan',
    'fs_scandir',
    'fs_stat',
    'fs_unlink',
    'fs_walk',
    'fs_cwd',
    'fs_home',
    'fs_expanduser',
    'fs_resolve',
    'fs_getmd5',
    'S3Path',
    'FSPath',
    'HttpPath',
    'HttpsPath',
    'StdioPath',
    'SmartPath',
]
